package com.sun.java.swing.plaf.motif;

import java.awt.event.MouseEvent;
import javax.swing.JSplitPane;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Insets;
import javax.swing.UIManager;
import javax.swing.plaf.basic.BasicSplitPaneUI;
import java.awt.Color;
import java.awt.Cursor;
import javax.swing.plaf.basic.BasicSplitPaneDivider;

public class MotifSplitPaneDivider extends BasicSplitPaneDivider
{
    private static final Cursor defaultCursor;
    public static final int minimumThumbSize = 6;
    public static final int defaultDividerSize = 18;
    protected static final int pad = 6;
    private int hThumbOffset;
    private int vThumbOffset;
    protected int hThumbWidth;
    protected int hThumbHeight;
    protected int vThumbWidth;
    protected int vThumbHeight;
    protected Color highlightColor;
    protected Color shadowColor;
    protected Color focusedColor;
    
    public MotifSplitPaneDivider(BasicSplitPaneUI ui) {
        super(ui);
        this.hThumbOffset = 30;
        this.vThumbOffset = 40;
        this.hThumbWidth = 12;
        this.hThumbHeight = 18;
        this.vThumbWidth = 18;
        this.vThumbHeight = 12;
        this.highlightColor = UIManager.getColor("SplitPane.highlight");
        this.shadowColor = UIManager.getColor("SplitPane.shadow");
        this.focusedColor = UIManager.getColor("SplitPane.activeThumb");
        this.setDividerSize(this.hThumbWidth + 6);
    }
    
    @Override
    public void setDividerSize(int dividerSize) {
        Insets insets = this.getInsets();
        int n = 0;
        if (this.getBasicSplitPaneUI().getOrientation() == 1) {
            if (insets != null) {
                n = insets.left + insets.right;
            }
        }
        else if (insets != null) {
            n = insets.top + insets.bottom;
        }
        if (dividerSize < 12 + n) {
            this.setDividerSize(12 + n);
        }
        else {
            int n2 = dividerSize - 6 - n;
            this.hThumbWidth = n2;
            this.vThumbHeight = n2;
            super.setDividerSize(dividerSize);
        }
    }
    
    @Override
    public void paint(Graphics g) {
        this.getBackground();
        Dimension size = this.getSize();
        g.setColor(this.getBackground());
        g.fillRect(0, 0, size.width, size.height);
        if (this.getBasicSplitPaneUI().getOrientation() == 1) {
            int n4 = size.width / 2;
            int n5 = n4 - this.hThumbWidth / 2;
            int hThumbOffset = this.hThumbOffset;
            g.setColor(this.shadowColor);
            g.drawLine(n4 - 1, 0, n4 - 1, size.height);
            g.setColor(this.highlightColor);
            g.drawLine(n4, 0, n4, size.height);
            g.setColor(this.splitPane.hasFocus() ? this.focusedColor : this.getBackground());
            g.fillRect(n5 + 1, hThumbOffset + 1, this.hThumbWidth - 2, this.hThumbHeight - 1);
            g.setColor(this.highlightColor);
            g.drawLine(n5, hThumbOffset, n5 + this.hThumbWidth - 1, hThumbOffset);
            g.drawLine(n5, hThumbOffset + 1, n5, hThumbOffset + this.hThumbHeight - 1);
            g.setColor(this.shadowColor);
            g.drawLine(n5 + 1, hThumbOffset + this.hThumbHeight - 1, n5 + this.hThumbWidth - 1, hThumbOffset + this.hThumbHeight - 1);
            g.drawLine(n5 + this.hThumbWidth - 1, hThumbOffset + 1, n5 + this.hThumbWidth - 1, hThumbOffset + this.hThumbHeight - 2);
        }
        else {
            int n = size.height / 2;
            int n2 = size.width - this.vThumbOffset;
            int n3 = size.height / 2 - this.vThumbHeight / 2;
            g.setColor(this.shadowColor);
            g.drawLine(0, n - 1, size.width, n - 1);
            g.setColor(this.highlightColor);
            g.drawLine(0, n, size.width, n);
            g.setColor(this.splitPane.hasFocus() ? this.focusedColor : this.getBackground());
            g.fillRect(n2 + 1, n3 + 1, this.vThumbWidth - 1, this.vThumbHeight - 1);
            g.setColor(this.highlightColor);
            g.drawLine(n2, n3, n2 + this.vThumbWidth, n3);
            g.drawLine(n2, n3 + 1, n2, n3 + this.vThumbHeight);
            g.setColor(this.shadowColor);
            g.drawLine(n2 + 1, n3 + this.vThumbHeight, n2 + this.vThumbWidth, n3 + this.vThumbHeight);
            g.drawLine(n2 + this.vThumbWidth, n3 + 1, n2 + this.vThumbWidth, n3 + this.vThumbHeight - 1);
        }
        super.paint(g);
    }
    
    @Override
    public Dimension getMinimumSize() {
        return this.getPreferredSize();
    }
    
    @Override
    public void setBasicSplitPaneUI(BasicSplitPaneUI splitPaneUI) {
        if (this.splitPane != null) {
            this.splitPane.removePropertyChangeListener(this);
            if (this.mouseHandler != null) {
                this.splitPane.removeMouseListener(this.mouseHandler);
                this.splitPane.removeMouseMotionListener(this.mouseHandler);
                this.removeMouseListener(this.mouseHandler);
                this.removeMouseMotionListener(this.mouseHandler);
                this.mouseHandler = null;
            }
        }
        if ((this.splitPaneUI = splitPaneUI) != null) {
            this.splitPane = splitPaneUI.getSplitPane();
            if (this.splitPane != null) {
                if (this.mouseHandler == null) {
                    this.mouseHandler = new MotifSplitPaneDivider.MotifMouseHandler();
                }
                this.splitPane.addMouseListener(this.mouseHandler);
                this.splitPane.addMouseMotionListener(this.mouseHandler);
                this.addMouseListener(this.mouseHandler);
                this.addMouseMotionListener(this.mouseHandler);
                this.splitPane.addPropertyChangeListener(this);
                if (this.splitPane.isOneTouchExpandable()) {
                    this.oneTouchExpandableChanged();
                }
            }
        }
        else {
            this.splitPane = null;
        }
    }
    
    private boolean isInThumb(int n, int n2) {
        Dimension size = this.getSize();
        int n4;
        int hThumbOffset;
        int n5;
        int n6;
        if (this.getBasicSplitPaneUI().getOrientation() == 1) {
            n4 = size.width / 2 - this.hThumbWidth / 2;
            hThumbOffset = this.hThumbOffset;
            n5 = this.hThumbWidth;
            n6 = this.hThumbHeight;
        }
        else {
            int n3 = size.height / 2;
            n4 = size.width - this.vThumbOffset;
            hThumbOffset = size.height / 2 - this.vThumbHeight / 2;
            n5 = this.vThumbWidth;
            n6 = this.vThumbHeight;
        }
        return n >= n4 && n < n4 + n5 && n2 >= hThumbOffset && n2 < hThumbOffset + n6;
    }
    
    private BasicSplitPaneDivider.DragController getDragger() {
        return this.dragger;
    }
    
    private JSplitPane getSplitPane() {
        return this.splitPane;
    }
    
    static BasicSplitPaneDivider.DragController access$100(MotifSplitPaneDivider motifSplitPaneDivider) {
        return motifSplitPaneDivider.getDragger();
    }
    
    static JSplitPane access$200(MotifSplitPaneDivider motifSplitPaneDivider) {
        return motifSplitPaneDivider.getSplitPane();
    }
    
    static boolean access$300(MotifSplitPaneDivider motifSplitPaneDivider, int n, int n2) {
        return motifSplitPaneDivider.isInThumb(n, n2);
    }
    
    static {
        defaultCursor = Cursor.getPredefinedCursor(0);
    }
    
    private class MotifMouseHandler extends BasicSplitPaneDivider.MouseHandler
    {
        @Override
        public void mousePressed(MouseEvent e) {
            if (e.getSource() == MotifSplitPaneDivider.this && MotifSplitPaneDivider.access$100(MotifSplitPaneDivider.this) == null && MotifSplitPaneDivider.access$200(MotifSplitPaneDivider.this).isEnabled() && MotifSplitPaneDivider.access$300(MotifSplitPaneDivider.this, e.getX(), e.getY())) {
                super.mousePressed(e);
            }
        }
        
        @Override
        public void mouseMoved(MouseEvent e) {
            if (MotifSplitPaneDivider.access$100(MotifSplitPaneDivider.this) != null) {
                return;
            }
            if (!MotifSplitPaneDivider.access$300(MotifSplitPaneDivider.this, e.getX(), e.getY())) {
                if (MotifSplitPaneDivider.this.getCursor() != MotifSplitPaneDivider.defaultCursor) {
                    MotifSplitPaneDivider.this.setCursor(MotifSplitPaneDivider.defaultCursor);
                }
                return;
            }
            else {
                super.mouseMoved(e);
                return;
            }
        }
    }
}
